
.. py:currentmodule:: pythreejs

Sphere
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: Sphere(center=[0,0,0], radius=0, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/math/Sphere


    .. py:attribute:: center

        .. sourcecode:: python

            Vector3(default_value=[0,0,0]).tag(sync=True)

    .. py:attribute:: radius

        .. sourcecode:: python

            CFloat(0, allow_none=False).tag(sync=True)

